.. _api_fsm:

.. py:module:: pynetdicom.fsm

State Machine (:mod:`pynetdicom.fsm`)
======================================

.. currentmodule:: pynetdicom.fsm

The Finite State Machine

State Machine
-------------

.. autosummary::
   :toctree: generated/

   StateMachine

Actions
-------

Association Establishment
~~~~~~~~~~~~~~~~~~~~~~~~~

.. autosummary::
   :toctree: generated/

   AE_1
   AE_2
   AE_3
   AE_4
   AE_5
   AE_6
   AE_7
   AE_8

Data Transfer
~~~~~~~~~~~~~

.. autosummary::
   :toctree: generated/

   DT_1
   DT_2

Association Release
~~~~~~~~~~~~~~~~~~~

.. autosummary::
   :toctree: generated/

   AR_1
   AR_2
   AR_3
   AR_4
   AR_5
   AR_6
   AR_7
   AR_8
   AR_9
   AR_10

Association Abort
~~~~~~~~~~~~~~~~~

.. autosummary::
   :toctree: generated/

   AA_1
   AA_2
   AA_3
   AA_4
   AA_5
   AA_6
   AA_7
   AA_8
